@@ -1,5 +1,6 @@
 import re
 import uuid
+import copy
 
 from typing import Dict
 
@@ -11,6 +12,35 @@ from .consts import CCML_DICTIONARY
 XML_TAG_REG = r"<((\/|)+[a-z]+)({gensym})+([a-z]+)"
 
 
+def __escape_polly_special_characters(ssml_text):
+    """
+    Escape special characters on Amazon polly related ssml.
+
+    Arguments:
+        ssml_text: (string) Target text.
+    """
+    ssml_t_c = copy.copy(ssml_text)
+    gensym_str = uuid.uuid4().hex[:5]
+
+    matches = re.finditer(r"<((\/|)+[a-z]+)([a-z])+([a-z]+)+(.*?)>", ssml_text,)
+
+    for m in matches:
+        ssml_t_c = ssml_t_c.replace(m[0], gensym_str)
+
+    splited_raw_text = ssml_t_c.split(gensym_str)
+
+    for t in splited_raw_text:
+        escaped = copy.copy(t)
+        escaped = escaped.replace('"', "&quot;")
+        escaped = escaped.replace("&", "&amp;")
+        escaped = escaped.replace("'", "&apos;")
+        escaped = escaped.replace("<", "&lt;")
+        escaped = escaped.replace(">", "&gt;")
+        ssml_text = ssml_text.replace(t, escaped)
+
+    return ssml_text
+
+
 def __convert_to_ccml(text: str, tags_dictionary: Dict):
     """
     Handle tag replacement in target text.
@@ -56,10 +86,12 @@ def ccml_to_aws_polly(text_input):
         text=text_input, valid_tags=[*aws_polly_ccml_tags, *common_ccml_tags]
     )
 
-    return __convert_to_ccml(
+    aws_polly_ssml = __convert_to_ccml(
         text=clean_text, tags_dictionary=CCML_DICTIONARY["aws_polly"]
     )
 
+    return __escape_polly_special_characters(ssml_text=aws_polly_ssml)
+
 
 def ccml_to_amazon(text_input):
     """
@@ -78,7 +110,10 @@ def ccml_to_amazon(text_input):
         text=text_input, valid_tags=[*amazon_ccml_tags, *common_ccml_tags]
     )
 
-    return __convert_to_ccml(text=clean_text, tags_dictionary=CCML_DICTIONARY["amazon"])
+    amazon_ssml = __convert_to_ccml(
+        text=clean_text, tags_dictionary=CCML_DICTIONARY["amazon"]
+    )
+    return __escape_polly_special_characters(ssml_text=amazon_ssml)
 
 
 def ccml_to_google(text_input):
